package cjson

import "github.com/secure-systems-lab/go-securesystemslib/cjson"

Index

Functions

func EncodeCanonical

func EncodeCanonical(obj interface{}) (out []byte, err error)

EncodeCanonical JSON canonicalizes the passed object and returns it as a byte slice. It uses the OLPC canonical JSON specification (see http://wiki.laptop.org/go/Canonical_JSON). If canonicalization fails the byte slice is nil and the second return value contains the error.

Source Files

canonicaljson.go

Version
v0.9.0 (latest)
Published
Dec 12, 2024
Platform
linux/amd64
Imports
7 packages
Last checked
10 months ago

Tools for package owners.